@@ -1,15 +1,15 @@
 rforcecom.query <-
 function(session, soqlQuery){
  # Load packages
- require(XML)
- require(RCurl)
+ if(!require(XML)){ install.packages("XML"); stop(!require(XML)) }
+ if(!require(RCurl)){ install.packages("RCurl"); stop(!require(RCurl)) }
  
  # Retrieve XML via REST API
  h <- basicHeaderGatherer()
  t <- basicTextGatherer()
  endpointPath <- rforcecom.api.getSoqlEndpoint(session['apiVersion'])
  URL <- paste(session['instanceURL'], endpointPath, curlEscape(soqlQuery), sep="")
- OAuthString <- paste("OAuth", session['sessionID'])
+ OAuthString <- paste("Bearer", session['sessionID'])
  httpHeader <- c("Authorization"=OAuthString, "Accept"="application/xml")
  curlPerform(url=URL, httpheader=httpHeader, headerfunction = h$update, writefunction = t$update, ssl.verifypeer=F)
  
@@ -21,7 +21,7 @@ function(session, soqlQuery){
  # Parse XML
  x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
  
- # Check whether it success
+ # Check whether it success or not
  errorcode <- NA
  errormessage <- NA
  try(errorcode <- iconv(xmlValue(x.root[['Error']][['errorCode']]), from="UTF-8", to=""), TRUE)
@@ -34,6 +34,14 @@ function(session, soqlQuery){
  xns <- getNodeSet(xmlParse(t$value()),'//records')
  xdf <- xmlToDataFrame(xns)
  xdf.iconv <- data.frame(lapply(xdf, iconv, from="UTF-8", to=""))
+ 
+ # Check whether it has next record
+ try(nextRecordsUrl <- iconv(xmlValue(x.root[['nextRecordsUrl']]), from="UTF-8", to=""), TRUE)
+ if(!is.na(nextRecordsUrl)){
+  nextRecords <- rforcecom.queryMore(session, nextRecordsUrl)
+  xdf.iconv <- rbind(xdf.iconv, nextRecords)
+ }
+ 
  return(data.frame(xdf.iconv))
 }
 
